@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_x_monotone_2.h $
+// $Id: Bezier_x_monotone_2.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Ron Wein     <wein@post.tau.ac.il>
@@ -318,11 +318,13 @@ public:
                            Bezier_cache& cache,
                            OutputIterator oi) const
   {
+    typedef boost::variant<Intersection_point, Self>    Intersection_result;
+
     // In case we have two x-monotone subcurves of the same Bezier curve,
     // check if they have a common left endpoint.
     if (_curve.is_same(cv._curve)) {
       if (left().is_same(cv.left()) || left().is_same(cv.right()))
-        *oi++ = Intersection_point(left(), 0);
+        *oi++ = Intersection_result(Intersection_point(left(), 0));
     }
 
     // Compute the intersections of the two sucurves. Note that for caching
@@ -339,7 +341,7 @@ public:
 
     // In case of overlap, just report the overlapping subcurve.
     if (do_ovlp) {
-      *oi++ = ovlp_cv;
+      *oi++ = Intersection_result(ovlp_cv);
       return oi;
     }
 
@@ -347,14 +349,14 @@ public:
     // xy-lexicorgraphical order, and insert them to the output iterator.
     std::sort(ipts.begin(), ipts.end(), Less_intersection_point(cache));
     for (auto ip_it = ipts.begin(); ip_it != ipts.end(); ++ip_it) {
-      *oi++ = *ip_it;
+      *oi++ = Intersection_result(*ip_it);
     }
 
     // In case we have two x-monotone subcurves of the same Bezier curve,
     // check if they have a common right endpoint.
     if (_curve.is_same(cv._curve)) {
       if (right().is_same(cv.left()) || right().is_same(cv.right())) {
-        *oi++ = Intersection_point(right(), 0);
+        *oi++ = Intersection_result(Intersection_point(right(), 0));
       }
     }
 
