@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Circle_segment_2.h $
+// $Id: Circle_segment_2.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -995,6 +995,9 @@ public:
   OutputIterator intersect(const Self& cv, OutputIterator oi,
                            Intersection_map* inter_map = nullptr) const
   {
+    typedef std::pair<Point_2, Multiplicity>            Intersection_point;
+    typedef boost::variant<Intersection_point, Self>    Intersection_result;
+
     // First check whether the two arcs have the same supporting curve.
     if (has_same_supporting_curve(cv)) {
       // Check for overlaps between the two arcs.
@@ -1002,7 +1005,7 @@ public:
 
       if (_compute_overlap(cv, overlap)) {
         // There can be just a single overlap between two x-monotone arcs:
-        *oi++ = overlap;
+        *oi++ = Intersection_result(overlap);
         return oi;
       }
 
@@ -1013,11 +1016,11 @@ public:
       // intersection points we report.
       Multiplicity mult = 0;
       if (left().equals(cv.left()) || left().equals(cv.right())) {
-        *oi++ = std::make_pair(left(), mult);
+        *oi++ = Intersection_result(std::make_pair(left(), mult));
       }
 
       if (right().equals(cv.right()) || right().equals(cv.left())) {
-        *oi++ = std::make_pair(right(), mult);
+        *oi++ = Intersection_result(std::make_pair(right(), mult));
       }
 
       return oi;
@@ -1069,7 +1072,7 @@ public:
       if (this->_is_between_endpoints (iter->first) &&
           cv._is_between_endpoints (iter->first))
       {
-        *oi++ = *iter;
+        *oi++ = Intersection_result(*iter);
       }
     }
 
@@ -1430,8 +1433,8 @@ protected:
     {
       // Actually compare the slopes.
       const bool swap_res = (sign_denom1 != sign_denom2);
-      const CoordNT A = NT(cv.y0() - y0())*p.x() + (y0()*cv.x0() - cv.y0()*x0());
-      const CoordNT B = NT(cv.x0() - x0())*p.y();
+      const CoordNT A = (cv.y0() - y0())*p.x() + (y0()*cv.x0() - cv.y0()*x0());
+      const CoordNT B = (cv.x0() - x0())*p.y();
 
       slope_res = CGAL::compare (A, B);
 
