@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_overlay_2.h $
+// $Id: Arr_overlay_2.h ac8b6d4 2022-06-10T07:59:39+02:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,7 +24,8 @@
  */
 
 #include <vector>
-#include <optional>
+#include <boost/optional/optional.hpp>
+#include <boost/mpl/if.hpp>
 #include <boost/mpl/or.hpp>
 #include <boost/type_traits.hpp>
 
@@ -171,14 +172,14 @@ overlay(const Arrangement_on_surface_2<GeometryTraitsA_2, TopologyTraitsA>& arr1
   typedef typename Agt2::Point_2                                A_point;
   typedef typename Bgt2::Point_2                                B_point;
   typedef typename Rgt2::Point_2                                Res_point;
-  static_assert(std::is_convertible<A_point, Res_point>::value);
-  static_assert(std::is_convertible<B_point, Res_point>::value);
+  CGAL_static_assertion((boost::is_convertible<A_point, Res_point>::value));
+  CGAL_static_assertion((boost::is_convertible<B_point, Res_point>::value));
 
   typedef typename Agt2::X_monotone_curve_2                     A_xcv;
   typedef typename Bgt2::X_monotone_curve_2                     B_xcv;
   typedef typename Rgt2::X_monotone_curve_2                     Res_xcv;
-  static_assert(std::is_convertible<A_xcv, Res_xcv>::value);
-  static_assert(std::is_convertible<B_xcv, Res_xcv>::value);
+  CGAL_static_assertion((boost::is_convertible<A_xcv, Res_xcv>::value));
+  CGAL_static_assertion((boost::is_convertible<B_xcv, Res_xcv>::value));
 
   typedef Arr_traits_basic_adaptor_2<Rgt2>              Gt_adaptor_2;
   typedef Arr_overlay_traits_2<Gt_adaptor_2, Arr_a, Arr_b>
@@ -230,7 +231,7 @@ overlay(const Arrangement_on_surface_2<GeometryTraitsA_2, TopologyTraitsA>& arr1
     xcvs_vec[i] = Ovl_x_monotone_curve_2(eit2->curve(), invalid_he1, he2);
   }
 
-  // Obtain an extended traits-class object and define the sweep-line visitor.
+  // Obtain a extended traits-class object and define the sweep-line visitor.
   const typename Arr_res::Traits_adaptor_2* traits_adaptor =
     arr.traits_adaptor();
 
@@ -246,8 +247,8 @@ overlay(const Arrangement_on_surface_2<GeometryTraitsA_2, TopologyTraitsA>& arr1
    * Use the form 'A a(*b);' and not ''A a = b;' to handle the case where A has
    * only an implicit constructor, (which takes *b as a parameter).
    */
-  std::conditional_t<std::is_same_v<Gt_adaptor_2, Ovl_gt2>,
-                     const Ovl_gt2&, Ovl_gt2>
+  typename boost::mpl::if_<std::is_same<Gt_adaptor_2, Ovl_gt2>,
+                           const Ovl_gt2&, Ovl_gt2>::type
     ex_traits(*traits_adaptor);
 
   Ovl_visitor visitor(&arr1, &arr2, &arr, &ovl_tr);
@@ -283,8 +284,8 @@ overlay(const Arrangement_on_surface_2<GeometryTraitsA_2, TopologyTraitsA>& arr1
     if (vit1->is_isolated()) {
       typename Arr_a::Vertex_const_handle v1 = vit1;
       pts_vec[i++] =
-        Ovl_point_2(vit1->point(), std::make_optional(Cell_handle_red(v1)),
-                    std::optional<Cell_handle_blue>());
+        Ovl_point_2(vit1->point(), boost::make_optional(Cell_handle_red(v1)),
+                    boost::optional<Cell_handle_blue>());
     }
   }
 
@@ -293,8 +294,8 @@ overlay(const Arrangement_on_surface_2<GeometryTraitsA_2, TopologyTraitsA>& arr1
     if (vit2->is_isolated()) {
       typename Arr_b::Vertex_const_handle v2 = vit2;
       pts_vec[i++] =
-        Ovl_point_2(vit2->point(), std::optional<Cell_handle_red>(),
-                    std::make_optional(Cell_handle_blue(v2)));
+        Ovl_point_2(vit2->point(), boost::optional<Cell_handle_red>(),
+                    boost::make_optional(Cell_handle_blue(v2)));
     }
   }
 
