@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Td_active_edge.h $
+// $Id: Td_active_edge.h 9c2f8ff 2023-01-13T18:51:28+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)         : Oren Nechushtan <theoren@math.tau.ac.il>
@@ -21,7 +21,7 @@
  */
 
 #include <CGAL/Arr_point_location/Trapezoidal_decomposition_2.h>
-#include <variant>
+#include <boost/variant.hpp>
 #include <memory>
 
 
@@ -145,13 +145,13 @@ public:
   //Dag_node* m_dag_node; //pointer to the search structure (DAG) node
 
   /*! Initialize the trapezoid's neighbors. */
-  inline void init_neighbors(std::optional<std::reference_wrapper<Td_map_item>> next)
+  inline void init_neighbors(boost::optional<Td_map_item&> next)
   {
-    set_next((next) ? next->get() : Td_map_item(0));
+    set_next((next) ? *next : Td_map_item(0));
   }
   /*! \copydoc init_neighbors
    *  \deprecated please use #init_neighbors */
-  CGAL_DEPRECATED inline void init_neighbours(std::optional<std::reference_wrapper<Td_map_item>> next)
+  CGAL_DEPRECATED inline void init_neighbours(boost::optional<Td_map_item&> next)
   { init_neighbors(next); }
 
   /*! Set the DAG node. */
@@ -199,10 +199,10 @@ public:
    /*! Constructor given Vertex & Halfedge handles. */
   Td_active_edge (Halfedge_const_handle he ,
                   Dag_node* node = 0,
-                  std::optional<std::reference_wrapper<Td_map_item>> next = std::nullopt)
+                  boost::optional<Td_map_item&> next = boost::none)
   {
 
-    PTR = new Data(he, (next) ? next->get() : Td_map_item(0), node);
+    PTR = new Data(he, (next) ? *next : Td_map_item(0), node);
     //m_dag_node = node;
   }
 
