@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_rat_arc/Rational_arc_d_1.h $
+// $Id: Rational_arc_d_1.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Oren Salzman <orenzalz@post.tau.ac.il >
@@ -100,9 +100,9 @@ public:
 
   typedef Algebraic_point_2                                 Point_2;
 
-  static_assert(std::is_same<Integer, Coefficient>::value);
-  static_assert(std::is_same<Polynomial_1,
-                       typename FT_poly_rat_1::Numerator_type>::value);
+  CGAL_static_assertion((std::is_same<Integer, Coefficient>::value));
+  CGAL_static_assertion((std::is_same<Polynomial_1,
+                       typename FT_poly_rat_1::Numerator_type>::value));
 
 public:
   const Rational_function& get_rational_function(const Polynomial_1& numerator,
@@ -2038,6 +2038,8 @@ public:
   OutputIterator intersect(const Self& arc, OutputIterator oi,
                            const Cache& cache) const
   {
+    typedef boost::variant<Intersection_point, Self>    Intersection_result;
+
     CGAL_precondition(this->is_valid());
     CGAL_precondition(this->is_continuous());
     CGAL_precondition(arc.is_valid());
@@ -2045,7 +2047,7 @@ public:
 
     if (this->equals(arc)) {
       Self overlap_arc(*this);
-      *oi++ = overlap_arc;
+      *oi++ = Intersection_result(overlap_arc);
       return oi;
     }
 
@@ -2168,7 +2170,7 @@ public:
               (this->SRC_AT_Y_MINUS_INFTY | this->SRC_AT_Y_PLUS_INFTY) == 0)
           {
             Intersection_point ip(p_left, 0);
-            *oi++ = ip;
+            *oi++ = Intersection_result(ip);
           }
 
           return oi;
@@ -2187,7 +2189,7 @@ public:
                            this->IS_DIRECTED_RIGHT | this->IS_CONTINUOUS |
                            this->IS_VALID);
 
-      *oi++ = overlap_arc;
+      *oi++ = Intersection_result(overlap_arc);
       return oi;
     }
 
@@ -2219,7 +2221,7 @@ public:
         Algebraic_point_2 p(this->_f, *x_iter);
         // Output the intersection point:
         Intersection_point ip(p, *m_iter);
-        *oi++ = ip;
+        *oi++ = Intersection_result(ip);
       }
     }
 
