@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_simple_point_location.h $
+// $Id: Arr_simple_point_location.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -26,7 +26,7 @@
 #include <CGAL/Arr_point_location_result.h>
 #include <CGAL/Arrangement_2/Arr_traits_adaptor_2.h>
 
-#include <optional>
+#include <boost/optional.hpp>
 
 namespace CGAL {
 
@@ -57,7 +57,11 @@ public:
   typedef Result_type                                    result_type;
 
 protected:
-  typedef typename std::optional<Result_type>          Optional_result_type;
+#if CGAL_ARR_POINT_LOCATION_VERSION < 2
+  typedef Result_type                                    Optional_result_type;
+#else
+  typedef typename boost::optional<Result_type>          Optional_result_type;
+#endif
 
   typedef typename Topology_traits::Dcel                 Dcel;
   typedef Arr_traits_basic_adaptor_2<Geometry_traits_2>  Traits_adaptor_2;
@@ -67,8 +71,13 @@ protected:
   const Traits_adaptor_2* m_geom_traits;    // Its associated geometry traits.
   const Topology_traits*  m_topol_traits;   // Its associated topology traits.
 
-  inline bool optional_empty(const std::optional<Result_type>& t) const { return (!t); }
-  inline const Result_type& optional_assign(const std::optional<Result_type>& t) const { return *t; }
+#if CGAL_ARR_POINT_LOCATION_VERSION < 2
+  inline bool optional_empty(const CGAL::Object& obj) const { return obj.empty(); }
+  inline const Result_type& optional_assign(const CGAL::Object& t) const { return t; }
+#else
+  inline bool optional_empty(const boost::optional<Result_type>& t) const { return (!t); }
+  inline const Result_type& optional_assign(const boost::optional<Result_type>& t) const { return *t; }
+#endif
 
   template<typename T>
   Result_type make_result(T t) const { return Result::make_result(t); }
