@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_spherical_gaussian_map_3/Arr_spherical_gaussian_map_3.h $
+// $Id: Arr_spherical_gaussian_map_3.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Efi Fogel         <efif@post.tau.ac.il>
@@ -155,14 +155,14 @@ public:
   OutputIterator insert(const Vector_3 & normal1, const Vector_3 & normal2,
                         OutputIterator oi)
   {
-    typedef std::variant<Point_2, X_monotone_curve_2>
+    typedef boost::variant<Point_2, X_monotone_curve_2>
       Make_x_monotone_result;
 
     std::list<Make_x_monotone_result> x_objects;
     make_x_monotone(normal1, normal2, std::back_inserter(x_objects));
 
     auto it = x_objects.begin();
-    const auto* xc = std::get_if<X_monotone_curve_2>(&(*it));
+    const auto* xc = boost::get<X_monotone_curve_2>(&(*it));
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
     Rcpp::Rcout << "1.a. insert_in_face_interior(" << *xc << ")" << std::endl;
 #endif
@@ -173,7 +173,7 @@ public:
     ++it;
     if (it == x_objects.end()) return oi;
 
-    xc = std::get_if<X_monotone_curve_2>(&(*it));
+    xc = boost::get<X_monotone_curve_2>(&(*it));
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
     Rcpp::Rcout << "1.b. insert_from_vertex(" << *xc << ")" << std::endl;
 #endif
@@ -196,14 +196,14 @@ public:
                         const Vector_3 & normal2,
                         OutputIterator oi)
   {
-    typedef std::variant<Point_2, X_monotone_curve_2>
+    typedef boost::variant<Point_2, X_monotone_curve_2>
       Make_x_monotone_result;
 
     std::list<Make_x_monotone_result> x_objects;
     make_x_monotone(normal1, normal2, std::back_inserter(x_objects));
 
     auto it = x_objects.begin();
-    const auto* xc = std::get_if<X_monotone_curve_2>(&(*it));
+    const auto* xc = boost::get<X_monotone_curve_2>(&(*it));
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
     Rcpp::Rcout << "2.a. insert_from_vertex(" << *xc << ", "
               << vertex1->point() << ")" << std::endl;
@@ -217,7 +217,7 @@ public:
     ++it;
     if (it == x_objects.end()) return oi;
 
-    xc = std::get_if<X_monotone_curve_2>(&(*it));
+    xc = boost::get<X_monotone_curve_2>(&(*it));
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
     Rcpp::Rcout << "2.b. insert_from_vertex(" << *xc << ")" << std::endl;
 #endif
@@ -240,7 +240,7 @@ public:
                         const Vector_3 & normal2, Vertex_handle vertex2,
                         OutputIterator oi)
   {
-    typedef std::variant<Point_2, X_monotone_curve_2>
+    typedef boost::variant<Point_2, X_monotone_curve_2>
       Make_x_monotone_result;
 
     std::list<Make_x_monotone_result> x_objects;
@@ -248,7 +248,7 @@ public:
 
     auto it = x_objects.begin();
     if (x_objects.size() == 1) {
-      const auto* xc = std::get_if<X_monotone_curve_2>(&(*it));
+      const auto* xc = boost::get<X_monotone_curve_2>(&(*it));
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
       Rcpp::Rcout << "3. insert_from_vertex(" << *xc << ")" << std::endl;
 #endif
@@ -259,8 +259,8 @@ public:
       return oi;
     }
 
-    const X_monotone_curve_2* xc1 = std::get_if<X_monotone_curve_2>(&(*it++));
-    const X_monotone_curve_2* xc2 = std::get_if<X_monotone_curve_2>(&(*it));
+    const X_monotone_curve_2* xc1 = boost::get<X_monotone_curve_2>(&(*it++));
+    const X_monotone_curve_2* xc2 = boost::get<X_monotone_curve_2>(&(*it));
 
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
     Rcpp::Rcout << "3.a. insert_from_vertex(" << *xc2 << ")" << std::endl;
@@ -295,13 +295,13 @@ public:
                         const Vector_3 & normal2, Vertex_handle vertex2,
                         OutputIterator oi)
   {
-    typedef std::variant<Point_2, X_monotone_curve_2>
+    typedef boost::variant<Point_2, X_monotone_curve_2>
       Make_x_monotone_result;
     std::list<Make_x_monotone_result> x_objects;
     make_x_monotone(normal1, normal2, std::back_inserter(x_objects));
     auto it = x_objects.begin();
     if (x_objects.size() == 1) {
-      const auto* xc = std::get_if<X_monotone_curve_2>(&(*it));
+      const auto* xc = boost::get<X_monotone_curve_2>(&(*it));
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
       Rcpp::Rcout << "4. insert_at_vertices(" << *xc << ")" << std::endl;
 #endif
@@ -309,8 +309,8 @@ public:
       return oi;
     }
 
-    const X_monotone_curve_2 * xc1 = std::get_if<X_monotone_curve_2>(&(*it++));
-    const X_monotone_curve_2 * xc2 = std::get_if<X_monotone_curve_2>(&(*it));
+    const X_monotone_curve_2 * xc1 = boost::get<X_monotone_curve_2>(&(*it++));
+    const X_monotone_curve_2 * xc2 = boost::get<X_monotone_curve_2>(&(*it));
 
 #if CGAL_ARR_SPHERICAL_GAUSSIAN_MAP_3_DEBUG==1
     Rcpp::Rcout << "4.a. insert_from_vertex(" << *xc1
