@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_tracing_traits_2.h $
+// $Id: Arr_tracing_traits_2.h ae3e2b6 2023-03-31T11:10:52+02:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Efi Fogel    <efif@post.tau.ac.il>
@@ -27,7 +27,7 @@
 #include <iostream>
 #include <list>
 
-#include <variant>
+#include <boost/variant.hpp>
 
 #include <CGAL/basic.h>
 #include <CGAL/Arr_enums.h>
@@ -532,7 +532,7 @@ public:
       Rcpp::Rcout << "make_x_monotone" << std::endl
                 << "  cv: " << cv << std::endl;
 
-      typedef std::variant<Point_2, X_monotone_curve_2>
+      typedef boost::variant<Point_2, X_monotone_curve_2>
         Make_x_monotone_result;
 
       std::list<Make_x_monotone_result> container;
@@ -541,12 +541,12 @@ public:
 
       size_t i = 0;
       for (auto it = container.begin(); it != container.end(); ++it) {
-        if (const auto* xcv = std::get_if<X_monotone_curve_2>(&*it)) {
+        if (const auto* xcv = boost::get<X_monotone_curve_2>(&*it)) {
           Rcpp::Rcout << "  result[" << i++ << "]: xcv: " << *xcv << std::endl;
           continue;
         }
 
-        if (const auto* p = std::get_if<Point_2>(&*it)) {
+        if (const auto* p = boost::get<Point_2>(&*it)) {
           Rcpp::Rcout << "  result[" << i++ << "]: p: " << *p << std::endl;
           continue;
         }
@@ -619,7 +619,7 @@ public:
                               OutputIterator oi) const
     {
       typedef std::pair<Point_2, Multiplicity>          Intersection_point;
-      typedef std::variant<Intersection_point, X_monotone_curve_2>
+      typedef boost::variant<Intersection_point, X_monotone_curve_2>
                                                         Intersection_result;
 
       if (! m_enabled) return m_object(xcv1, xcv2, oi);
@@ -633,22 +633,22 @@ public:
 
       unsigned int i = 0;
       for (const auto& item : container) {
-        const X_monotone_curve_2* xcv = std::get_if<X_monotone_curve_2>(&item);
+        const X_monotone_curve_2* xcv = boost::get<X_monotone_curve_2>(&item);
         if (xcv != nullptr) {
           Rcpp::Rcout << "  result[" << i++ << "]: xcv: " << *xcv << std::endl;
-          *oi++ = *xcv;
           continue;
         }
 
-        const Intersection_point* ip = std::get_if<Intersection_point>(&item);
+        const Intersection_point* ip = boost::get<Intersection_point>(&item);
         if (ip != nullptr) {
           Rcpp::Rcout << "  result[" << i++ << "]: p: " << ip->first
                     << ", multiplicity: " << ip->second << std::endl;
-          *oi++ = *ip;
           continue;
         }
       }
 
+      for (auto it = container.begin(); it != container.end(); ++it) *oi++ = *it;
+      container.clear();
       return oi;
     }
   };
