@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_traits_adaptor_2_dispatching.h $
+// $Id: Arr_traits_adaptor_2_dispatching.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -17,6 +17,7 @@
 
 
 #include <boost/mpl/bool.hpp>
+#include <boost/mpl/if.hpp>
 #include <boost/mpl/and.hpp>
 #include <boost/mpl/or.hpp>
 #include <boost/mpl/not.hpp>
@@ -58,22 +59,25 @@ public:
 
 private:
 
-  typedef std::conditional_t<
-       std::is_same_v< Arr_smaller_implementation_tag, Arr_use_traits_tag >,
-       std::true_type, std::false_type > Smaller_traits;
+  typedef boost::mpl::bool_< true > true_;
+  typedef boost::mpl::bool_< false > false_;
 
-  typedef std::conditional_t<
-       std::is_same_v< Arr_larger_implementation_tag, Arr_use_traits_tag >,
-       std::true_type, std::false_type > Larger_traits;
+  typedef boost::mpl::if_<
+       std::is_same< Arr_smaller_implementation_tag, Arr_use_traits_tag >,
+       true_, false_ > Smaller_traits;
+
+  typedef boost::mpl::if_<
+       std::is_same< Arr_larger_implementation_tag, Arr_use_traits_tag >,
+       true_, false_ > Larger_traits;
 
 public:
 
   //! the result type (if one side asks for traits, then ask traits!
   //! Or vice versa: If both ask for dummy, then dummy!)
-  typedef std::conditional_t<
-              Smaller_traits::value || Larger_traits::value,
+  typedef typename boost::mpl::if_<
+              boost::mpl::or_< Smaller_traits, Larger_traits >,
               Arr_use_traits_tag,
-              Arr_use_dummy_tag > type;
+              Arr_use_dummy_tag >::type type;
 
 };
 
