@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arrangement_zone_2.h $
+// $Id: Arrangement_zone_2.h ccdb5a0 2023-02-15T14:36:44+02:00 Efi Fogel
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Ron Wein          <wein@post.tau.ac.il>
@@ -55,68 +55,65 @@ namespace CGAL {
 template <typename Arrangement_, typename ZoneVisitor_>
 class Arrangement_zone_2 {
 public:
-  using Arrangement_2 = Arrangement_;
-  using Geometry_traits_2 = typename Arrangement_2::Geometry_traits_2;
-  using Topology_traits = typename Arrangement_2::Topology_traits;
+  typedef Arrangement_                                   Arrangement_2;
+  typedef typename Arrangement_2::Geometry_traits_2      Geometry_traits_2;
+  typedef typename Arrangement_2::Topology_traits        Topology_traits;
 
 protected:
-  using Traits_adaptor_2 = Arr_traits_adaptor_2<Geometry_traits_2>;
+  typedef Arr_traits_adaptor_2<Geometry_traits_2>        Traits_adaptor_2;
 
-  using Left_side_category = typename Traits_adaptor_2::Left_side_category;
-  using Bottom_side_category = typename Traits_adaptor_2::Bottom_side_category;
-  using Top_side_category = typename Traits_adaptor_2::Top_side_category;
-  using Right_side_category = typename Traits_adaptor_2::Right_side_category;
+  typedef typename Traits_adaptor_2::Left_side_category   Left_side_category;
+  typedef typename Traits_adaptor_2::Bottom_side_category Bottom_side_category;
+  typedef typename Traits_adaptor_2::Top_side_category    Top_side_category;
+  typedef typename Traits_adaptor_2::Right_side_category  Right_side_category;
 
-  static_assert(Arr_sane_identified_tagging<Left_side_category,
-                                            Bottom_side_category,
+  CGAL_static_assertion((Arr_sane_identified_tagging<Left_side_category,
+                                                    Bottom_side_category,
                                                     Top_side_category,
-                                                    Right_side_category>::value);
-  // Categories for dispatching
-  using Are_all_sides_oblivious_category =
-    typename Arr_all_sides_oblivious_category<Left_side_category,
-                                              Bottom_side_category,
-                                              Top_side_category,
-                                              Right_side_category>::result;
-
-  using Left_or_right_sides_category =
-    typename Arr_two_sides_category<Left_side_category,
-                                    Right_side_category>::result;
+                                                    Right_side_category>::value));
 
 public:
-  using Visitor = ZoneVisitor_;
+  typedef ZoneVisitor_                                   Visitor;
 
-  using Vertex_handle = typename Arrangement_2::Vertex_handle;
-  using Halfedge_handle = typename Arrangement_2::Halfedge_handle;
-  using Face_handle = typename Arrangement_2::Face_handle;
+  typedef typename Arrangement_2::Vertex_handle          Vertex_handle;
+  typedef typename Arrangement_2::Halfedge_handle        Halfedge_handle;
+  typedef typename Arrangement_2::Face_handle            Face_handle;
 
-  using Visitor_result = std::pair<Halfedge_handle, bool>;
+  typedef std::pair<Halfedge_handle, bool>               Visitor_result;
 
-  using Point_2 = typename Geometry_traits_2::Point_2;
-  using X_monotone_curve_2 = typename Geometry_traits_2::X_monotone_curve_2;
-  using Multiplicity = typename Geometry_traits_2::Multiplicity;
+  typedef typename Geometry_traits_2::Point_2            Point_2;
+  typedef typename Geometry_traits_2::X_monotone_curve_2 X_monotone_curve_2;
+  typedef typename Geometry_traits_2::Multiplicity       Multiplicity;
 
 protected:
-  // General types
-  using Vertex_const_handle = typename Arrangement_2::Vertex_const_handle;
-  using Halfedge_const_handle = typename Arrangement_2::Halfedge_const_handle;
-  using Face_const_handle = typename Arrangement_2::Face_const_handle;
+  typedef typename Arr_all_sides_oblivious_category<Left_side_category,
+                                                    Bottom_side_category,
+                                                    Top_side_category,
+                                                    Right_side_category>::result
+    Are_all_sides_oblivious_category;
 
-  using Ccb_halfedge_circulator =
-    typename Arrangement_2::Ccb_halfedge_circulator;
+  typedef typename Arrangement_2::Vertex_const_handle   Vertex_const_handle;
+  typedef typename Arrangement_2::Halfedge_const_handle Halfedge_const_handle;
+  typedef typename Arrangement_2::Face_const_handle     Face_const_handle;
+
+  typedef typename Arrangement_2::Ccb_halfedge_circulator
+    Ccb_halfedge_circulator;
 
   // Types used for caching intersection points:
-  using Intersection_point = std::pair<Point_2, Multiplicity>;
-  using Intersection_result =
-    std::variant<Intersection_point, X_monotone_curve_2>;
-  using Optional_intersection = std::optional<Intersection_result>;
-  using Intersect_list = std::list<Intersection_result>;
-  using Intersect_map = std::map<const X_monotone_curve_2*, Intersect_list>;
+  typedef std::pair<Point_2, Multiplicity>              Intersection_point;
+  typedef boost::variant<Intersection_point, X_monotone_curve_2>
+                                                        Intersection_result;
+  typedef boost::optional<Intersection_result>          Optional_intersection;
+  typedef std::list<Intersection_result>                Intersect_list;
+  typedef std::map<const X_monotone_curve_2*, Intersect_list>
+                                                        Intersect_map;
+  typedef typename Intersect_map::iterator              Intersect_map_iterator;
 
-  using Curves_set = std::set<const X_monotone_curve_2*>;
-  using Curves_set_iterator = typename Curves_set::iterator;
+  typedef std::set<const X_monotone_curve_2*>           Curves_set;
+  typedef typename Curves_set::iterator                 Curves_set_iterator;
 
-  using Pl_result = Arr_point_location_result<Arrangement_2>;
-  using Pl_result_type = typename Pl_result::Type;
+  typedef Arr_point_location_result<Arrangement_2>      Pl_result;
+  typedef typename Pl_result::Type                      Pl_result_type;
 
   // Data members:
   Arrangement_2& m_arr;                 // The associated arrangement.
@@ -196,7 +193,8 @@ public:
    * \param pl A point-location object associated with the arrangement.
    */
   template <typename PointLocation>
-  void init(const X_monotone_curve_2& cv, const PointLocation& pl) {
+  void init(const X_monotone_curve_2& cv, const PointLocation& pl)
+  {
     // Set the curve and check whether its left end has boundary conditions.
     m_cv = cv;
 
@@ -269,7 +267,8 @@ private:
    */
   bool do_overlap_impl(const X_monotone_curve_2& cv1,
                        const X_monotone_curve_2& cv2,
-                       const Point_2& p, Arr_all_sides_oblivious_tag) const {
+                       const Point_2& p, Arr_all_sides_oblivious_tag) const
+  {
     return m_geom_traits->compare_y_at_x_right_2_object()(cv1, cv2, p) == EQUAL;
   }
 
@@ -337,7 +336,7 @@ private:
   Optional_intersection
   _compute_next_intersection(Halfedge_handle he,
                              bool skip_first_point,
-                             Arr_parameter_space& intersection_location);
+                             bool& intersect_on_right_boundary);
 
   /*! Remove the next intersection of m_cv with the given halfedge from the map.
    * \param he A handle to the halfedge.
@@ -382,7 +381,8 @@ private:
   { return (_is_to_right_impl(p, he, Are_all_sides_oblivious_category())); }
 
   bool _is_to_right_impl(const Point_2& p, Halfedge_handle he,
-                         Arr_all_sides_oblivious_tag) const {
+                         Arr_all_sides_oblivious_tag) const
+  {
     return (((he->direction() == ARR_LEFT_TO_RIGHT) &&
              m_geom_traits->compare_xy_2_object()(p, he->target()->point()) ==
              LARGER) ||
@@ -394,33 +394,12 @@ private:
   bool _is_to_right_impl(const Point_2& p, Halfedge_handle he,
                          Arr_not_all_sides_oblivious_tag) const;
 
-  /*! Check whether an intersection point is valid. A valid intersection point
-   * must be to the left of the left end of the curve involved.
-   */
-  bool is_intersection_valid(const Point_2& ip,
-                             Arr_parameter_space& intersection_location) const {
-    return is_intersection_valid_impl(ip, intersection_location,
-                                      Left_or_right_sides_category());
-  }
-
-  bool is_intersection_valid_impl(const Point_2& ip,
-                                  Arr_parameter_space& intersection_location,
-                                  Arr_all_sides_oblivious_tag) const;
-
-  bool is_intersection_valid_impl(const Point_2& ip,
-                                  Arr_parameter_space& intersection_location,
-                                  Arr_has_identified_side_tag) const;
-
-  bool is_intersection_valid_impl(const Point_2& ip,
-                                  Arr_parameter_space& intersection_location,
-                                  Arr_boundary_cond_tag) const;
-
   /*! Compute the (lexicographically) leftmost intersection of the query
    * curve with a given halfedge on the boundary of a face in the arrangement.
    */
   void
   _leftmost_intersection(Ccb_halfedge_circulator he_curr, bool on_boundary,
-                         Arr_parameter_space& leftmost_location);
+                         bool& leftmost_on_right_boundary);
 
   /*! Compute the (lexicographically) leftmost intersection of the query
    * curve with the boundary of a given face in the arrangement.
